==> iteda-0.8.5.tar.gz: iteda-0.8.5/setup.py <==
from distutils.core import setup
setup(
  name = 'iteda',         # How you named your package folder (MyLib)
  packages = ['iteda'],   # Chose the same as "name"
  version = '0.8.5',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This is a menu to control an integrating sphere through an serial interface (rs232)',   # Give a short description about your library
  long_description='To use this properly, just navigate to : ~/.local/lib/python2.7/site-packages/iteda , and execute the iteda.py file, thats all',
  author = 'victor esparza',                   # Type in your name
  author_email = 'vicmaresparza@gmail.com',      # Type in your E-Mail
  url = 'https://gitlab.com/fabriziodifran/esfera-codigo-verilog',   # Provide either the link to your github or to your website
  #download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['MENU', 'UART', 'SPHERE'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
          'numpy',
          'pyserial',
          'argparse',
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 2.7',      #Specify which pyhton versions that you want to support
  ],
)

==> iteda-0.8.6.tar.gz: iteda-0.8.6/setup.py <==
from distutils.core import setup
setup(
  name = 'iteda',         # How you named your package folder (MyLib)
  packages = ['iteda'],   # Chose the same as "name"
  version = '0.8.6',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This is a menu to control an integrating sphere through an serial interface (rs232)',   # Give a short description about your library
  long_description="To use this properly, just navigate to : ~/.local/lib/python2.7/site-packages/iteda , and execute the iteda.py file, thats all.",
  author = 'victor esparza',                   # Type in your name
  author_email = 'vicmaresparza@gmail.com',      # Type in your E-Mail
  url = 'https://gitlab.com/fabriziodifran/esfera-codigo-verilog',   # Provide either the link to your github or to your website
  #download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['MENU', 'UART', 'SPHERE'],   # Keywords that define your package best
    install_requires=[            # I get to this in a second
          'numpy',
          'pyserial',
          'argparse',
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 2.7',      #Specify which pyhton versions that you want to support
  ],
)
